import React, { memo, useState, useCallback, useEffect, useRef } from 'react';
import { View, Text } from 'react-native';
import Slider from './components/Slider';
import PlayPauseButton from './components/PlayPauseButton';
import Sound from 'react-native-sound';
import { secondsToMinutesAndSeconds } from './utils/millisToMinutesAndSeconds';
import { getPlayedPercentage } from './utils/getPlayedPercentage';
import { getPlayedPosition } from './utils/getPlayerPosition';
import { styles } from './styles';
const THREE_HUNDRED_MILLIS = 300;
const AudioComponent = props => {
  var _props$audio;
  const [duration, setDuration] = useState(0);
  const [currentTime, setCurrentTime] = useState(0);
  const [playing, setPlaying] = useState(false);
  const interval = useRef();
  const sound = useRef(new Sound((_props$audio = props.audio) === null || _props$audio === void 0 ? void 0 : _props$audio.fileUrl, Sound.MAIN_BUNDLE, error => {
    if (error) {
      console.log('failed to load the sound', error);
      return;
    } else {
      var _sound$current;
      setDuration(Math.floor((_sound$current = sound.current) === null || _sound$current === void 0 ? void 0 : _sound$current.getDuration()));
    }
  }));
  useEffect(() => () => {
    var _sound$current2;
    (_sound$current2 = sound.current) === null || _sound$current2 === void 0 ? void 0 : _sound$current2.release();
    sound.current = null;
    clearInterval(interval.current);
  }, []);
  const updateCurrentTime = useCallback(() => {
    var _sound$current3;
    (_sound$current3 = sound.current) === null || _sound$current3 === void 0 ? void 0 : _sound$current3.getCurrentTime(seconds => {
      setCurrentTime(Math.floor(seconds));
    });
  }, [sound.current]);
  const togglePlayback = useCallback(() => {
    if (playing) {
      var _sound$current4;
      (_sound$current4 = sound.current) === null || _sound$current4 === void 0 ? void 0 : _sound$current4.pause();
      setPlaying(false);
      clearInterval(interval.current);
    } else {
      var _sound$current5;
      (_sound$current5 = sound.current) === null || _sound$current5 === void 0 ? void 0 : _sound$current5.play(() => {
        var _sound$current6;
        (_sound$current6 = sound.current) === null || _sound$current6 === void 0 ? void 0 : _sound$current6.release();
        setPlaying(false);
      });
      interval.current = setInterval(updateCurrentTime, THREE_HUNDRED_MILLIS);
      setPlaying(true);
    }
  }, [sound.current, playing]);
  const onSliderChange = value => {
    var _sound$current7;
    (_sound$current7 = sound.current) === null || _sound$current7 === void 0 ? void 0 : _sound$current7.setCurrentTime(getPlayedPosition({
      duration,
      playedPercentage: value
    }));
  };
  return /*#__PURE__*/React.createElement(View, {
    style: styles.audio
  }, /*#__PURE__*/React.createElement(PlayPauseButton, {
    isPlaying: playing,
    onPress: togglePlayback
  }), /*#__PURE__*/React.createElement(Text, {
    style: styles.duration
  }, secondsToMinutesAndSeconds(currentTime), " /", ' ', secondsToMinutesAndSeconds(duration)), /*#__PURE__*/React.createElement(Slider, {
    onValueChange: onSliderChange,
    value: getPlayedPercentage({
      currentTime,
      duration
    })
  }));
};
export default /*#__PURE__*/memo(AudioComponent);
//# sourceMappingURL=index.js.map